# frozen_string_literal: true

require_relative '../commands/start'
require_relative '../commands/pull_plugins'
require_relative '../commands/stop'
require_relative '../commands/show'
require_relative '../commands/shell'
require_relative '../commands/help'
require_relative '../commands/logs'

module Redmine
  module CLI
    class CommandFactory
      def initialize(args, config)
        @arguments = args
        @config    = config
      end

      def command
        case @arguments.command
        when Redmine::CLI::Parser::COMMAND_START
          Redmine::Commands::Start.new(@arguments, @config)
        when Redmine::CLI::Parser::COMMAND_LIST
          Redmine::Commands::List.new
        when Redmine::CLI::Parser::COMMAND_INSTALL_PLUGINS
          Redmine::Commands::PullPlugins.new(@arguments)
        when Redmine::CLI::Parser::COMMAND_STOP
          Redmine::Commands::Stop.new(@arguments)
        when Redmine::CLI::Parser::COMMAND_SHOW
          Redmine::Commands::Show.new(@arguments)
        when Redmine::CLI::Parser::COMMAND_SHELL
          Redmine::Commands::Shell.new(@arguments)
        when Redmine::CLI::Parser::COMMAND_HELP
          Redmine::Commands::Help.new
        when Redmine::CLI::Parser::COMMAND_LOGS
          Redmine::Commands::Logs.new(@arguments)
        else
          raise Redmine::CLI::UnclearCommand, @arguments.command
        end
      end
    end
  end
end
