# frozen_string_literal: true

require 'optparse'

require_relative './arguments'

require_relative './../commands/start'
require_relative './../commands/list'

module Redmine
  module CLI
    class UnclearCommand < StandardError; end
    class Parser
      COMMANDS = [
        COMMAND_START           = 'start',
        COMMAND_STOP            = 'stop',
        COMMAND_LIST            = 'list',
        COMMAND_SHOW            = 'show',
        COMMAND_SHELL           = 'shell',
        COMMAND_INSTALL_PLUGINS = 'install-plugins',
        COMMAND_HELP            = 'help',
        COMMAND_LOGS            = 'logs',
      ].freeze

      attr_reader :arguments

      def initialize(args)
        parse(args)
      end

      private

      def parse(args)
        @arguments = ::Redmine::CLI::Arguments.new
        opt_parser = OptionParser.new do |opts|
          opts.on('-p', '--privileged', 'Run in privileged mode') do |p|
            @arguments.privileged = p
          end
        end

        opt_parser.parse!(args)
        if (args.size > 0)
          parse_remainings(args)
        else
          print_help
        end
      end

      def parse_remainings(args)
        command = args.shift
        case command
        when COMMAND_START
          @arguments.command = COMMAND_START
        when COMMAND_STOP
          process_stop_command(args)
        when COMMAND_LIST
          @arguments.command = COMMAND_LIST
        when COMMAND_SHOW
          process_show_command(args)
        when COMMAND_SHELL
          process_shell_command(args)
        when COMMAND_HELP
          print_help
        when COMMAND_LOGS
          process_logs_command(args)
        when COMMAND_INSTALL_PLUGINS
          process_install_plugins_command(args)
        else
          puts "Unknown command #{command}"
          raise UnclearCommand, command
        end
      end

      def process_stop_command(args)
        @arguments.command = COMMAND_STOP
        @arguments.instance_name = args.shift
      end

      def process_show_command(args)
        @arguments.command = COMMAND_SHOW
        @arguments.instance_name = args.shift
      end

      def process_logs_command(args)
        @arguments.command = COMMAND_LOGS
        @arguments.instance_name = args.shift
      end

      def process_shell_command(args)
        @arguments.command = COMMAND_SHELL
        @arguments.instance_name = args.shift
      end

      def process_install_plugins_command(args)
        @arguments.command = COMMAND_INSTALL_PLUGINS
        @arguments.config_path = args.shift
        @arguments.plugins_path = args.shift
      end

      def print_help
        @arguments.command = COMMAND_HELP
      end
    end
  end
end
