# frozen_string_literal: true

module Redmine
  module Commands
    module Docker
      class Create
        def initialize(config, arguments)
          @config    = config
          @arguments = arguments
        end

        def command_line
          [
            cli_prefix,
            name,
            privileged_mode,
            env_vars,
            ports,
            mount,
            image,
          ].join(' ')
        end

        private

        def image
          'redmineup/demo-base'
        end

        def mount
          '--mount source=redmine-pg,target=/var/lib/postgresql/9.5/main'
        end

        def ports
          "-p #{@config.port}:#{@config.port}"
        end

        def env_vars
          [
            port_env,
            config_env_vars
          ].flatten.join(' ')
        end

        def port_env
          "-e PORT=#{@config.port}"
        end

        def config_env_vars
          @config.env.map do |k, v|
            "-e #{k}=#{v}"
          end.join(' ')
        end

        def privileged_mode
          return '' unless @arguments.privileged
          '--privileged'
        end

        def cli_prefix
          'docker create'
        end

        def name
          "--name=#{@config.name}"
        end
      end
    end
  end
end
