# frozen_string_literal: true

require 'ostruct'

require_relative '../utils/system'
require_relative './list_printer'

module Redmine
  module Commands
    DOCKER_LIST_COMMAND = 'docker ps'
    class List
      def results
        parse(Redmine::Utils::System.new.execute_and_return('docker ps'))
      end

      def execute
        Redmine::Commands::ListPrinter.new.print(results)
      end

      private

      def parse(docker_ps_output)
        results = docker_ps_output.split("\n")[1..-1].map do |line|
          process_line(line)
        end
        results.select { |result| result.name =~ /^redmine-run__/ }
      end

      def process_line(line)
        line_tokens = line.split(/\s{2,}/)
        OpenStruct.new(
          container_id: line_tokens[0],
          image: line_tokens[1],
          command: line_tokens[2],
          created: line_tokens[3],
          status: line_tokens[4],
          ports: line_tokens[5],
          name: line_tokens[6]
        )
      end
    end
  end
end
