# frozen_string_literal: true

require 'yaml'

module Redmine
  class Config
    def initialize(filename)
      @filename = filename
      parse
    end

    def ruby_version
      @config['ruby']['version']
    end

    def redmine_version
      @config['redmine']['version']
    end

    def port
      @config['server']['port']
    end

    def name
      "redmine-run__#{@config['name']}"
    end

    def plugins
      @config['plugins']
    end

    def env
      @config['env']
    end

    def yaml
      YAML.dump(@config)
    end

    private

    def parse
      content = File.read(@filename)
      @config = YAML.safe_load(content)
    end
  end
end
