# frozen_string_literal: true

require_relative './system'

module Redmine
  module Utils
    class PluginInstaller
      def initialize(plugins_folder, plugin_props)
        @plugins_folder = plugins_folder
        @plugin         = plugin_props
      end

      def install
        if folder_exists?
          update_plugin
        else
          clone_plugin
        end
        bundle
        migrate
      end

      private

      def folder_exists?
        File.directory?(dest_dir)
      end

      def dest_dir
        File.join(@plugins_folder, @plugin.folder)
      end

      def shell
        @shell ||= Redmine::Utils::System.new
      end

      def clone_plugin
        shell.execute(
          "git clone #{@plugin.git} #{dest_dir}"
        )
      end

      def update_plugin
        shell.execute(
          "cd #{dest_dir}; git fetch -a; git reset --hard #{commit_specification}"
        )
      end

      def commit_specification
        return @plugin.tag if @plugin.tag
        return "origin/#{@plugin.branch}" if @plugin.branch
      end

      def bundle
        shell.execute(
          "cd #{dest_dir}; cd ..; bundle"
        )
      end

      def migrate
        shell.execute(
          "cd #{dest_dir}; cd ..; bundle exec rake redmine:plugins"
        )
      end
    end
  end
end
